@@ -169,6 +169,9 @@ struct _MetaDisplay
   Atom atom_metacity_toggle_verbose;
   Atom atom_metacity_update_counter;
   Atom atom_sync_counter;
+  Atom atom_gnome_panel_action;
+  Atom atom_gnome_panel_action_main_menu;
+  Atom atom_gnome_panel_action_run_dialog;
   
   /* This is the actual window from focus events,
    * not the one we last set
@@ -246,6 +249,9 @@ struct _MetaDisplay
   MetaResizePopup *grab_resize_popup;
   GTimeVal    grab_last_moveresize_time;
   Time        grab_motion_notify_time;
+#ifdef HAVE_XKB
+  int         xkb_base_event_type;
+#endif
 #ifdef HAVE_XSYNC
   /* alarm monitoring client's _METACITY_UPDATE_COUNTER */
   XSyncAlarm  grab_update_alarm;
@@ -256,8 +262,8 @@ struct _MetaDisplay
   int             n_screen_bindings;
   MetaKeyBinding *window_bindings;
   int             n_window_bindings;
-  int min_keycode;
-  int max_keycode;
+  unsigned int min_keycode;
+  unsigned int max_keycode;
   KeySym *keymap;
   int keysyms_per_keycode;
   XModifierKeymap *modmap;
@@ -404,10 +410,10 @@ typedef enum
 
 } MetaTabList;
 
-GSList* meta_display_get_tab_list (MetaDisplay   *display,
-                                   MetaTabList    type,
-                                   MetaScreen    *screen,
-                                   MetaWorkspace *workspace);
+GList* meta_display_get_tab_list (MetaDisplay   *display,
+                                  MetaTabList    type,
+                                  MetaScreen    *screen,
+                                  MetaWorkspace *workspace);
 
 MetaWindow* meta_display_get_tab_next (MetaDisplay   *display,
                                        MetaTabList    type,
