@@ -134,6 +134,11 @@ static void handle_move_to_workspace  (MetaDisplay    *display,
                                        MetaWindow     *window,
                                        XEvent         *event,
                                        MetaKeyBinding *binding);
+static void handle_move_to_workspace_flip  (MetaDisplay    *display,
+                                            MetaScreen     *screen,
+                                            MetaWindow     *window,
+                                            XEvent         *event,
+                                            MetaKeyBinding *binding);
 static void handle_workspace_switch   (MetaDisplay    *display,
                                        MetaScreen     *screen,
                                        MetaWindow     *window,
@@ -381,13 +386,13 @@ static const MetaKeyHandler window_handlers[] = {
     GINT_TO_POINTER (10) },
   { META_KEYBINDING_MOVE_WORKSPACE_12, handle_move_to_workspace,
     GINT_TO_POINTER (11) },
-  { META_KEYBINDING_MOVE_WORKSPACE_LEFT, handle_move_to_workspace,
+  { META_KEYBINDING_MOVE_WORKSPACE_LEFT, handle_move_to_workspace_flip,
     GINT_TO_POINTER (META_MOTION_LEFT) },
-  { META_KEYBINDING_MOVE_WORKSPACE_RIGHT, handle_move_to_workspace,
+  { META_KEYBINDING_MOVE_WORKSPACE_RIGHT, handle_move_to_workspace_flip,
     GINT_TO_POINTER (META_MOTION_RIGHT) },
-  { META_KEYBINDING_MOVE_WORKSPACE_UP, handle_move_to_workspace,
+  { META_KEYBINDING_MOVE_WORKSPACE_UP, handle_move_to_workspace_flip,
     GINT_TO_POINTER (META_MOTION_UP) },
-  { META_KEYBINDING_MOVE_WORKSPACE_DOWN, handle_move_to_workspace,
+  { META_KEYBINDING_MOVE_WORKSPACE_DOWN, handle_move_to_workspace_flip,
     GINT_TO_POINTER (META_MOTION_DOWN) },
   { META_KEYBINDING_RAISE_OR_LOWER, handle_raise_or_lower, NULL},
   { META_KEYBINDING_RAISE, handle_raise, NULL},
@@ -2596,7 +2601,10 @@ handle_toggle_desktop (MetaDisplay    *display,
                        MetaKeyBinding *binding)
 {
   if (screen->showing_desktop)
-    meta_screen_unshow_desktop (screen);
+    {
+      meta_screen_unshow_desktop (screen);
+      meta_screen_focus_top_window (screen, NULL);
+    }
   else
     meta_screen_show_desktop (screen);
 }
@@ -2983,11 +2991,12 @@ handle_toggle_sticky      (MetaDisplay    *display,
 }
 
 static void
-handle_move_to_workspace  (MetaDisplay    *display,
-                           MetaScreen     *screen,
-                           MetaWindow     *window,
-                           XEvent         *event,
-                           MetaKeyBinding *binding)
+do_handle_move_to_workspace  (MetaDisplay    *display,
+                              MetaScreen     *screen,
+                              MetaWindow     *window,
+                              XEvent         *event,
+                              MetaKeyBinding *binding,
+                              gboolean        flip)
 {
   int which;
   MetaWorkspace *workspace;
@@ -3012,7 +3021,8 @@ handle_move_to_workspace  (MetaDisplay    *display,
     {
       /* Activate second, so the window is never unmapped */
       meta_window_change_workspace (window, workspace);
-      meta_workspace_activate (workspace);
+      if (flip)
+        meta_workspace_activate (workspace);
     }
   else
     {
@@ -3020,6 +3030,35 @@ handle_move_to_workspace  (MetaDisplay    *display,
     }  
 }
 
+static void
+handle_move_to_workspace  (MetaDisplay    *display,
+                           MetaScreen     *screen,
+                           MetaWindow     *window,
+                           XEvent         *event,
+                           MetaKeyBinding *binding)
+{
+  do_handle_move_to_workspace (display,
+                               screen,
+                               window,
+                               event,
+                               binding,
+                               FALSE);
+}
+static void
+handle_move_to_workspace_flip  (MetaDisplay    *display,
+                                MetaScreen     *screen,
+                                MetaWindow     *window,
+                                XEvent         *event,
+                                MetaKeyBinding *binding)
+{
+  do_handle_move_to_workspace (display,
+                               screen,
+                               window,
+                               event,
+                               binding,
+                               TRUE);
+}
+
 static void 
 handle_raise_or_lower (MetaDisplay    *display,
                        MetaScreen     *screen,
